@@ -17,19 +17,6 @@ use mro_compat;
 print  "Benchmark of get_linear_isa() for 'direct' vs. 'cached'\n";
 printf "Perl %vd on $^O\n";
 
-
-print "\nCache disabled (i.e. first access)\n";
-cmpthese timethese -1 => {
-	'mroc (direct)' => sub{
-		mro_compat::method_changed_in('D');
-		my $isa_ref = mro_compat::get_linear_isa_dfs('D');
-	},
-	'mroc (cached)' => sub{
-		mro_compat::method_changed_in('D');
-		my $isa_ref = mro_compat::get_linear_isa('D');
-	},
-};
-
 print "Cache enabled\n";
 cmpthese timethese -1 => {
 	'mroc (direct)' => sub{
@@ -39,3 +26,15 @@ cmpthese timethese -1 => {
 		my $isa_ref = mro_compat::get_linear_isa('D');
 	},
 };
+
+print "\nCache disabled (i.e. the first access)\n";
+cmpthese timethese -1 => {
+	'mroc (direct)' => sub{
+		mro_compat::method_changed_in('D');
+		my $isa_ref = mro_compat::get_linear_isa_dfs('D');
+	},
+	'mroc (cached)' => sub{
+		mro_compat::method_changed_in('D');
+		my $isa_ref = mro_compat::get_linear_isa('D');
+	},
+};
